import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface GroupMemberConfig extends cdktf.TerraformMetaArguments {
    /**
     * The object ID of the group you want to add the member to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/group_member.html#group_object_id GroupMember#group_object_id}
     *
     * @stability stable
     */
    readonly groupObjectId: string;
    /**
     * The object ID of the principal you want to add as a member to the group.
     *
     * Supported object types are Users, Groups or Service Principals
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/group_member.html#member_object_id GroupMember#member_object_id}
     *
     * @stability stable
     */
    readonly memberObjectId: string;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/group_member.html#timeouts GroupMember#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: GroupMemberTimeouts;
}
/**
 * @stability stable
 */
export interface GroupMemberTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/group_member.html#create GroupMember#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/group_member.html#delete GroupMember#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/group_member.html#read GroupMember#read}.
     *
     * @stability stable
     */
    readonly read?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/group_member.html#update GroupMember#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/azuread/r/group_member.html azuread_group_member}.
 *
 * @stability stable
 */
export declare class GroupMember extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/azuread/r/group_member.html azuread_group_member} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: GroupMemberConfig);
    private _groupObjectId;
    /**
     * @stability stable
     */
    get groupObjectId(): string;
    /**
     * @stability stable
     */
    set groupObjectId(value: string);
    /**
     * @stability stable
     */
    get groupObjectIdInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _memberObjectId;
    /**
     * @stability stable
     */
    get memberObjectId(): string;
    /**
     * @stability stable
     */
    set memberObjectId(value: string);
    /**
     * @stability stable
     */
    get memberObjectIdInput(): string;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): GroupMemberTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: GroupMemberTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): GroupMemberTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
