import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ServicePrincipalPasswordConfig extends cdktf.TerraformMetaArguments {
    /**
     * Arbitrary map of values that, when changed, will trigger rotation of the password.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/service_principal_password.html#rotate_when_changed ServicePrincipalPassword#rotate_when_changed}
     *
     * @stability stable
     */
    readonly rotateWhenChanged?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * The object ID of the service principal for which this password should be created.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/service_principal_password.html#service_principal_id ServicePrincipalPassword#service_principal_id}
     *
     * @stability stable
     */
    readonly servicePrincipalId: string;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/service_principal_password.html#timeouts ServicePrincipalPassword#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: ServicePrincipalPasswordTimeouts;
}
/**
 * @stability stable
 */
export interface ServicePrincipalPasswordTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/service_principal_password.html#create ServicePrincipalPassword#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/service_principal_password.html#delete ServicePrincipalPassword#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/service_principal_password.html#read ServicePrincipalPassword#read}.
     *
     * @stability stable
     */
    readonly read?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/service_principal_password.html#update ServicePrincipalPassword#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/azuread/r/service_principal_password.html azuread_service_principal_password}.
 *
 * @stability stable
 */
export declare class ServicePrincipalPassword extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/azuread/r/service_principal_password.html azuread_service_principal_password} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ServicePrincipalPasswordConfig);
    /**
     * @stability stable
     */
    get displayName(): string;
    /**
     * @stability stable
     */
    get endDate(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get keyId(): string;
    private _rotateWhenChanged?;
    /**
     * @stability stable
     */
    get rotateWhenChanged(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set rotateWhenChanged(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRotateWhenChanged(): void;
    /**
     * @stability stable
     */
    get rotateWhenChangedInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _servicePrincipalId;
    /**
     * @stability stable
     */
    get servicePrincipalId(): string;
    /**
     * @stability stable
     */
    set servicePrincipalId(value: string);
    /**
     * @stability stable
     */
    get servicePrincipalIdInput(): string;
    /**
     * @stability stable
     */
    get startDate(): string;
    /**
     * @stability stable
     */
    get value(): string;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ServicePrincipalPasswordTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ServicePrincipalPasswordTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ServicePrincipalPasswordTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
